@@ -19,12 +19,12 @@ import math
 import re
 from typing import List, Optional
 
-from addons.widman.widget import Widget
-from core.enums.exit_code import ExitCode
-from core.exception.exceptions import WidgetExecutionError
-from core.tools.commons import sysout
-from modules.cli.icons.font_awesome.widget_icons import WidgetIcons
-from modules.cli.tui.extra.minput.minput import MenuInput, minput
+from hspylib.addons.widman.widget import Widget
+from hspylib.core.enums.exit_code import ExitCode
+from hspylib.core.exception.exceptions import WidgetExecutionError
+from hspylib.core.tools.commons import sysout
+from hspylib.modules.cli.icons.font_awesome.widget_icons import WidgetIcons
+from hspylib.modules.cli.tui.extra.minput.minput import MenuInput, minput
 
 
 class WidgetTimeCalc(Widget):
