@@ -15,7 +15,7 @@
 from argparse import ArgumentError, ArgumentParser
 from typing import Any
 
-from modules.cli.application.parser_action import ParserAction
+from hspylib.modules.cli.application.parser_action import ParserAction
 
 
 class ArgumentsBuilder:
